@@ -1,10 +1,9 @@
-from __future__ import annotations
-
+from typing import Dict, List, Tuple
 
 import math
 
 
-_next_fast_len_cache: dict[tuple[int, list[int]], int] = {}
+_next_fast_len_cache: Dict[Tuple[int, List[int]], int] = {}
 
 
 def _next_fast_len_impl(n, primes):
